@@ -17,6 +17,7 @@ import os
 
 import tensorflow as tf
 from tensorflow import keras
+from tensorflow.keras.callbacks import EarlyStopping
 from tensorflow.keras.layers import (LSTM,
                                      Dense,
                                      Flatten,
@@ -113,7 +114,9 @@ class BasicMultStepUniVar(UniVariateMultiStep):
         layer_config: dict = {'layer0': (64, 1, 'relu'), 'layer1': (32, 1, 'relu'),
         'layer2': (2), 'layer3': (50, 'relu'), 'layer4': (100, 'relu')}):
             Builds encoder decoder CNN structure.
-        fit_model(self, epochs: int, show_progress: int = 1):
+        fit_model(self, epochs: int, show_progress: int = 1,
+        validation_split: float = 0.20, batch_size: int = 10,
+        **callback_setting: dict):
             Fitting model onto provided data.
         model_blueprint(self):
             Print blueprint of layer structure.
@@ -724,21 +727,34 @@ class BasicMultStepUniVar(UniVariateMultiStep):
             epochs: int,
             show_progress: int = 1,
             validation_split: float = 0.20,
-            batch_size: int = 10):
+            batch_size: int = 10,
+            **callback_setting: dict):
         '''Trains the model on data provided. Perfroms validation.
             Parameters:
                 epochs (int): Number of epochs to train the model.
                 show_progress (int): Prints training progress.
                 validation_split (float): Determines size of Validation data.
                 batch_size (int): Batch size of input data.
+                callback_settings (dict): Create a Keras EarlyStopping object.
         '''
-        self.details = self.model.fit(
-            self.input_x,
-            self.input_y,
-            validation_split=validation_split,
-            batch_size=batch_size,
-            epochs=epochs,
-            verbose=show_progress)
+        if callback_setting == {}:
+            self.details = self.model.fit(
+                self.input_x,
+                self.input_y,
+                validation_split=validation_split,
+                batch_size=batch_size,
+                epochs=epochs,
+                verbose=show_progress)
+        else:
+            callback = EarlyStopping(**callback_setting)
+            self.details = self.model.fit(
+                self.input_x,
+                self.input_y,
+                validation_split=validation_split,
+                batch_size=batch_size,
+                epochs=epochs,
+                verbose=show_progress,
+                callbacks=[callback])
         return self.details
 
     def model_blueprint(self):
